@@ -5,7 +5,7 @@ import os
 
 # Function to convert
 # Pass in the path to the file
-def extract(file_name):                     
+def extracter(file_name):                     
     r=sr.Recognizer()
     clip=mp.VideoFileClip(file_name)
     conv_file="audio"
